glue\_genes.glue\_genomics\_data.geojson\_factory.read\_geojson
===============================================================

.. currentmodule:: glue_genes.glue_genomics_data.geojson_factory

.. autofunction:: read_geojson